@@ -61,14 +61,14 @@ async def generate(
         #
         #     return response
 
-        # if response.data and request.response_format == "url":
-        #     urls = [
-        #         f"""https://s3ai.cn/fal/files/panda/{Path(dict(image_data).get("url", "")).name}"""
-        #
-        #         for image_data in response.data
-        #     ]
-        #
-        #     response.data = [{"url": url} for url in urls] + response.data
+        if response.data and request.response_format == "oss_url":
+            urls = [
+                f"""https://s3ai.cn/fal/files/panda/{Path(dict(image_data).get("url", "")).name}"""
+
+                for image_data in response.data
+            ]
+
+            response.data = [{"url": url} for url in urls] + response.data
 
         send_message_for_images(response.data)
 
@@ -90,9 +90,7 @@ async def generate(
     if request.model in {"Qwen-Image", "FLUX_1-Krea-dev"} and request.model.endswith(("lora",)):
         return await gitee_images_generate(request, api_key)
 
-    if request.model.startswith("qwen-image"):  # 仅支持单图
-        if request.image and isinstance(request.image, list):
-            request.image = request.image[-1]
+    if request.model.startswith("qwen-image"):
         return await QwenCompletions(api_key=api_key).generate(request)
 
     if request.model.startswith(("google/gemini", "gemini")):  # openrouter
@@ -111,7 +109,7 @@ async def generate(
     if request.model.startswith("doubao"):
         base_url = base_url or os.getenv("VOLC_BASE_URL")
         api_key = api_key or await get_valid_token_for_volc()
-        api_key = np.random.choice(api_key.split())
+        api_key = api_key.split()[0]  # 一个号并发足够
 
         request.stream = False
         request.watermark = False
