@@ -9,6 +9,7 @@
 # @Description  :
 
 from openai import AsyncOpenAI
+from openai import APIStatusError
 
 from meutils.pipe import *
 from meutils.io.files_utils import to_base64, to_url
@@ -111,19 +112,30 @@ async def generate(request: ImageRequest, api_key: Optional[str] = None):
     data = to_openai_images_params(request)
     # logger.debug(data)
 
-    # 代理
-    http_client = None
-    if request.user == 'proxy':
-        http_client = httpx.AsyncClient(proxy=await get_one_proxy(), timeout=60)
+    try:
+        client = AsyncOpenAI(base_url=BASE_URL, api_key=api_key)
+        response = await client.images.generate(**data)
+        # logger.debug(response)
 
-    client = AsyncOpenAI(base_url=BASE_URL, api_key=api_key, http_client=http_client, timeout=60)
-    response = await client.images.generate(**data)
-    response.model = ""
-    # logger.debug(response)
+    except APIStatusError as e:
+        logger.debug(e)
+        # logger.debug(e.response.json())
+        # logger.debug(e.response.status_code)
+
+        if e.response.status_code > 403 and any(i in BASE_URL for i in {"siliconflow", "modelscope"}):
+            proxy = await get_one_proxy()
+            client = AsyncOpenAI(
+                base_url=BASE_URL,
+                api_key=api_key,
+                http_client=httpx.AsyncClient(proxy=proxy, timeout=100)
+            )
+            response = await client.images.generate(**data)
+        raise e
 
     # response.data[0].url = response.data[0].url.replace(r'\u0026', '&')
-    send_message(f"request: {request.model}\n{request.prompt}\nresponse: {response.data[0].url}",)
+    send_message(f"request: {request.model}\n{request.prompt}\nresponse: {response.data[0].url}", )
 
+    response.model = ""
     response.data[0].url = await to_url(response.data[0].url, content_type="image/png")
     if request.response_format == "b64_json":
         b64_json = await to_base64(response.data[0].url)
@@ -140,10 +152,11 @@ if __name__ == '__main__':
     from meutils.pipe import *
 
     data = {
-        # "model": "flux-schnell",
-        "model": "black-forest-labs/FLUX.1-Krea-dev",
+        "model": "flux-schnell",
+        # "model": "black-forest-labs/FLUX.1-Krea-dev",
 
-        "prompt": "(Chinese dragon soaring through the clouds).(majestic, colorful, mythical, powerful, ancient).(DSLR camera).(wide-angle lens).(dawn)(fantasy photography).(Kodak Ektar 100)",
+        "prompt": "a dog",
+        # "prompt": "(Chinese dragon soaring through the clouds).(majestic, colorful, mythical, powerful, ancient).(DSLR camera).(wide-angle lens).(dawn)(fantasy photography).(Kodak Ektar 100)",
         "negative_prompt": "",
         "n": 1,
         # "response_format": "url",
@@ -173,8 +186,11 @@ if __name__ == '__main__':
     # request = FluxImageRequest(model="flux", prompt="a dog", size="1024x1024", num_inference_steps=1)
     # request = FluxImageRequest(model="flux-pro", prompt="a dog", size="10x10", num_inference_steps=1)
 
-    data = {'model': 'black-forest-labs/FLUX.1-Krea-dev', 'prompt': '画一个2025年电脑如何一键重装系统win10教程详解的封面图', 'n': 1,
-            'size': '680x400'}
+    # data = {
+    #     'model': 'black-forest-labs/FLUX.1-Krea-dev',
+    #     'prompt': '画一个2025年电脑如何一键重装系统win10教程详解的封面图', 'n': 1,
+    #     'size': '1024x1024'
+    # }
     request = FluxImageRequest(**data)
 
     print(request)
