@@ -7,6 +7,8 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
+import os
+
 import httpx
 
 from meutils.pipe import *
@@ -193,6 +195,20 @@ async def make_request_with_cache(
     )
 
 
+def get_base_url(base_url: Optional[str], headers: Optional[dict] = None):
+    headers = headers or {}
+    mapping = {
+        "volc": os.getenv("VOLC_BASE_URL"),
+    }
+    base_url = (
+            mapping.get(base_url, base_url)
+            or headers.get("base-url") or headers.get("x-base-url")
+            or "https://api.siliconflow.cn/v1"
+    )
+
+    return base_url
+
+
 if __name__ == '__main__':
     from meutils.io.files_utils import to_bytes
 
@@ -237,7 +253,7 @@ if __name__ == '__main__':
     }
     FAL_KEY = "aa5c047f-2621-4be2-9cee-9857a630aa11:b06782c97dffb50bfd6eebb63f49c624"
 
-    headers ={"Authorization": f"key {FAL_KEY}"}
+    headers = {"Authorization": f"key {FAL_KEY}"}
     arun(make_request(
         base_url=base_url,
         path=path,
