@@ -18,7 +18,9 @@ from meutils.schemas.openai_types import CompletionRequest
 from meutils.schemas.video_types import VideoRequest
 
 from meutils.db.redis_db import redis_aclient
-from meutils.llm.check_utils import check_token_for_volc
+# from meutils.llm.check_utils import check_token_for_volc
+from meutils.llm.check_utils import check_token_for_volc_with_cache as check_token_for_volc
+
 from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series
 
 from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks
@@ -45,6 +47,7 @@ async def get_valid_token(tokens: Optional[list] = None, batch_size: Optional[in
         volc_tokens = volc_tokens.decode()
         if recheck:
             valid_tokens = await check_token_for_volc(volc_tokens.split('\n'))
+
             volc_tokens = '\n'.join(valid_tokens)
 
         return volc_tokens
@@ -279,7 +282,7 @@ c4356b58-4aa3-4a52-b907-b40c4dd2e502
 
     # arun(get_valid_token(['a93ea9a5-3831-47b8-863a-57e10233f922']))
     # arun(get_valid_token(batch_size=2))
-    arun(get_valid_token())
+    arun(get_valid_token(batch_size=2, seed=int(time.time())))
     # arun(get_valid_token(recheck=True))
 
 """
