@@ -76,7 +76,6 @@ if __name__ == '__main__':
 
     task_id = "celery-task-meta-ca94c602-a2cc-4db5-afe4-763f30df8a18"
 
-
     # arun(redis_aclient.get('celery-task-meta-72d59447-1f88-4727-8067-8244c2268faa'))
     #
     # arun(redis_aclient.select(1))
@@ -91,13 +90,17 @@ if __name__ == '__main__':
     # async def main():
     #     return await redis_aclient.lpop("redis_key")
 
-
     # arun(main())
 
     # r = redis_client.sadd('set1', 'a', 'b', 'c')
     # r = redis_client.sadd('set1', 'd')
     # k="meutils.config_utils.lark_utils.commonaget_spreadsheet_values()[(＇feishu_url＇, ＇https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=Gvm9dt＇), (＇to_dataframe＇, True)]	"
     # redis_client.delete(k)
-    print(redis_client.get('test'))
+    # print(redis_client.get('test'))
 
-    print(redis_client.delete("k"))
+    # print(redis_client.delete("k"))
+
+    # print(type(redis_client.type('pods').decode()))
+    # print(redis_client.get('xxsadasd').decode())
+
+    redis_client.set("pods", "10.219.11.231 114.66.55.228")
