@@ -214,7 +214,7 @@ async def check_token_for_sophnet(api_key, threshold: float = 1):
 
 #
 @retrying()
-# @rcache(ttl=3 * 24 * 3600, skip_cache_func=skip_cache_func)
+# @rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[str] = None):
     if not isinstance(api_key, str):
         return await check_tokens(
@@ -281,6 +281,11 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
         return False
 
 
+@rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)
+async def check_token_for_volc_with_cache(api_key, threshold: float = 1, purpose: Optional[str] = None):
+    return await check_token_for_volc(api_key, threshold=threshold, purpose=purpose)
+
+
 @retrying()
 async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_name: Optional[str] = None):
     if not isinstance(api_key, str):
@@ -429,7 +434,9 @@ if __name__ == '__main__':
 
     # arun(check_token_for_ppinfra("sk_F0kgPyCMTzmOH_-VCEJucOK8HIrbnLGYm_IWxBToHZQ"))
 
-    arun(check_token_for_volc(["827b41d2-7e8c-46e2-9854-0720ca1bd2e4"]))
+    # arun(check_token_for_volc(["827b41d2-7e8c-46e2-9854-0720ca1bd2e4"]))
+    r = arun(check_token_for_volc_with_cache(["1"]))
+
     # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))
     # arun(check_token_for_volc("8a5af7cb-42a3-4391-ac40-9d0f4502acde", purpose='seedance'))
 
