@@ -45,21 +45,21 @@ class Completions(object):
                           "doubao-seed-1-6-vision-250815"
                       } - {request.model}
             request.model = np.random.choice(list(choices))
+
         elif request.model.startswith("doubao-seed"):
             request.thinking = {"type": "enabled"}
             choices = {
-                          "doubao-seed-1.6-250615",
                           "doubao-seed-1-6-250615",
                           "doubao-seed-1-6-vision-250815",
                           "doubao-seed-1-6-thinking-250615",
                           "doubao-seed-1-6-thinking-250715"
                       } - {request.model}
             request.model = np.random.choice(list(choices))
-
+            if request.model == "doubao-seed-1-6-thinking-250615":
+                request.max_tokens = 16000
 
         elif request.model.startswith(("doubao-1-5-thinking",)):  # thinking
             request.thinking = None
-
             choices = {
                           "doubao-1-5-thinking-pro-250415",
                           "doubao-1-5-thinking-pro-m-250428",
@@ -84,6 +84,17 @@ class Completions(object):
                           "doubao-1-5-ui-tars-250428",
                       } - {request.model}
             request.model = np.random.choice(list(choices))
+
+        elif request.model.startswith(("deepseek-",)):  # deepseek => v3-1
+            if request.model.startswith("deepseek-r"):
+                request.thinking = {"type": "enabled"}
+
+            choices = {
+                          "deepseek-v3-1-250821",
+                          "deepseek-v3-1-terminus",
+                      } - {request.model}
+            request.model = np.random.choice(list(choices))
+
         # todo vision
 
         ###########################################################################
@@ -172,7 +183,9 @@ if __name__ == '__main__':
         # model="Qwen/Qwen3-8B1",
         # model="doubao-1-5-thinking",
         # model="doubao-1-5",
-        model="doubao-seed",
+        # model="doubao-seed",
+        model="doubao-seed-1-6-250615",
+
         thinking={"type": "disabled"},
         messages=[
             {
@@ -199,7 +212,9 @@ if __name__ == '__main__':
                 # }
             ]}
         ],
-        stream=False,
+        # stream=False,
+        # stream=True,
+
         max_tokens=10,
     )
     # arun(Completions().create(request))
@@ -275,4 +290,13 @@ if __name__ == '__main__':
 
     api_key = os.getenv("VOLC_API_KEY")
     base_url = os.getenv("VOLC_BASE_URL")
+
+
+    async def main():
+        async for i in await Completions(api_key=api_key, base_url=base_url).create(request):
+            logger.debug(i)
+
+
     arun(Completions(api_key=api_key, base_url=base_url).create(request))
+
+    # arun(main())
