@@ -7,6 +7,7 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
+import shortuuid
 from aiostream import stream
 
 from meutils.pipe import *
@@ -39,8 +40,12 @@ async def chat_for_image(
         if request.model.startswith('fal'):
             urls = await to_url_fal(image_urls, content_type="image/png")  # 国外友好
             image = urls
+
+        elif request.model.startswith("doubao-seed"):
+            image = image_urls  # b64
+
         else:
-            urls = await to_url(image_urls, content_type="image/png")  # 数组
+            urls = await to_url(image_urls, ".png", content_type="image/png")  # 数组
             image = urls
 
     image_request = ImageRequest(
@@ -91,7 +96,11 @@ async def chat_for_image(
     future_task = asyncio.create_task(generate(image_request))  # 异步执行
 
     async def gen():
-        text = image_request.model_dump_json(exclude_none=True).replace("free", "")
+        exclude = None
+        if len(str(image_request.image)) > 1000:
+            exclude = {"image"}
+
+        text = image_request.model_dump_json(exclude_none=True, exclude=exclude).replace("free", "")
         for i in f"""> 🖌️正在绘画\n\n```json\n{text}\n```\n\n""":
             await asyncio.sleep(0.05)
             yield i
@@ -155,6 +164,7 @@ async def chat_for_video(
 
 if __name__ == '__main__':
     from meutils.apis.images.generations import generate
+
     request = CompletionRequest(
         model="deepseek-r1-Distill-Qwen-1.5B",
         messages=[
