@@ -80,8 +80,8 @@ FAL_MODELS = {
     # recraft
     "fal-ai/recraft/upscale/crisp": 0.004 * FAL_,
     "fal-ai/recraft/upscale/creative": 0.25 * FAL_,
-    "fal-ai/recraft/v3/image-to-image": 0.006 * FAL_,  # 0.04 0.08 vec
-    "fal-ai/recraft/v3/text-to-image": 0.006 * FAL_,
+    "fal-ai/recraft/v3/image-to-image": 0.06 * FAL_,  # 0.04 0.08 vec
+    "fal-ai/recraft/v3/text-to-image": 0.06 * FAL_,
 
     # veo
     "fal-ai/veo3/fast": 3.2 * FAL_,  # 2 3.2
@@ -102,19 +102,50 @@ FAL_MODELS = {
     "fal-ai/wan/v2.2-5b/text-to-video": 0.15 * FAL_,
     "fal-ai/wan/v2.2-5b/image-to-video": 0.15 * FAL_,
 
+    "fal-ai/wan-25-preview/text-to-video": 0.5 * FAL_,
+    "fal-ai/wan-25-preview/image-to-video": 0.5 * FAL_,
+
     # pika
     "fal-ai/pika/v2.2/text-to-video": 0.45 * FAL,
     "fal-ai/pika/v2.2/image-to-video": 0.45 * FAL,
     "fal-ai/pika/v2.2/pikascenes": 0.45 * FAL,
-
 }
 
 FAL_MODELS = {
     model.replace("fal-ai", "fal").replace("{{BASE_URL}}/", "").replace("/", "-").lower(): v for model, v in
-    FAL_MODELS.items()}
+    FAL_MODELS.items()
+}
+
+REPLICATE_MODELS = {
+    'recraft-ai/recraft-v3': 0.04 * FAL,
+    'recraft-ai/recraft-v3-svg': 0.08 * FAL,
+    'stability-ai/stable-diffusion-3.5-large': 0.065 * FAL,
+    'stability-ai/stable-diffusion-3.5-medium': 0.02 * FAL,
+    'stability-ai/stable-diffusion-3.5-large-turbo': 0.04 * FAL,
+    'stability-ai/stable-diffusion-3': 0.04 * FAL,
+    'stability-ai/sdxl': 0.04 * FAL,
+    'stability-ai/stable-diffusion': 0.04 * FAL,
+
+    'ideogram-ai/ideogram-v2': 0.09 * FAL,
+    'ideogram-ai/ideogram-v2-turbo': 0.03 * FAL,
+
+    'black-forest-labs/flux-schnell': 0.003 * FAL,
+    'black-forest-labs/flux-dev': 0.025 * FAL,
+    'black-forest-labs/flux-pro': 0.04 * FAL,
+    'black-forest-labs/flux-1.1-pro': 0.04 * FAL,
+    'black-forest-labs/flux-1.1-pro-ultra': 0.06 * FAL,
+
+    'black-forest-labs/flux-fill-pro': 0.05 * FAL,
+    'black-forest-labs/flux-canny-pro': 0.05 * FAL,
+    'black-forest-labs/flux-depth-pro': 0.05 * FAL,
+
+    'black-forest-labs/flux-kontext-max': 0.04 * FAL,
+    'black-forest-labs/flux-kontext-pro': 0.08 * FAL,
+}
 
 MODEL_PRICE = {
     **FAL_MODELS,
+    **REPLICATE_MODELS,
 
     "nano-banana": 0.04 * 3,
     "gemini-2.5-flash-image": 0.04 * 3,
@@ -123,6 +154,8 @@ MODEL_PRICE = {
 
     "qwen-image": 0.05,
     "qwen-image-edit": 0.05,
+    "qwen-image-2509": 0.05,
+    "qwen-image-edit-2509": 0.05,
 
     "wan-ai-wan2.1-t2v-14b": 1,
     "wan-ai-wan2.1-t2v-14b-turbo": 1,
@@ -184,9 +217,9 @@ MODEL_PRICE = {
 
     # 火山
     "jimeng-video-3.0": 0.5,
-    "doubao-seedream-3-0-t2i-250415": 0.1,
-    "doubao-seededit-3-0-i2i-250628": 0.1,
     "doubao-seedream-4-0-250828": 0.1,
+    "doubao-seedream-3-0-t2i-250415": 0.05,
+    "doubao-seededit-3-0-i2i-250628": 0.05,
 
     "doubao-seedance-1-0-pro": 0.5,  # 480 1080
     "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
@@ -650,6 +683,9 @@ MODEL_RATIO = {
 
     "grok-4": 1.5,
 
+    "grok-4-fast-reasoning": 0.1,
+    "grok-4-fast-non-reasoning": 0.1,
+
     # 定制
     "lingxi-all": 1,
 
@@ -760,6 +796,11 @@ MODEL_RATIO = {
     "qwen3-235b-a22b-instruct-2507": 1,
     "qwen3-235b-a22b-thinking-2507": 1,
 
+    "qwen3-vl-plus": 0.5,
+    "qwen3-vl-235b-a22b": 0.5,
+    "qwen3-vl-235b-a22b-instruct": 1,
+    "qwen3-vl-235b-a22b-thinking": 1,
+
     "qwen3-coder-plus": 2,
     "qwen3-coder-plus-2025-07-22": 2,
 
@@ -851,6 +892,9 @@ MODEL_RATIO = {
     "deepseek-v3-1-250821": 2,
     "deepseek-v3-1-think": 2,
 
+    "deepseek-v3-1-terminus": 2,
+    "deepseek-v3.1-terminus": 2,
+
     "deepseek-chat-8k": 0.5,
     "deepseek-chat-64k": 5,
     "deepseek-chat-164k": 5,
@@ -1304,6 +1348,8 @@ COMPLETION_RATIO = {
     "grok-3-mini-beta": 5 / 3,
     "grok-3-mini-fast-beta": 4 / 0.6,
     "grok-4": 5,
+    "grok-4-fast-reasoning": 2.5,
+    "grok-4-fast-non-reasoning": 2.5,
 
     "grok-code-fast-1": 7.5,
 
@@ -1488,6 +1534,11 @@ COMPLETION_RATIO = {
     "qwen-vl-max-latest": 3,
     "qwen-vl-plus-latest": 3,
 
+    "qwen3-vl-plus": 10,
+    "qwen3-vl-235b-a22b": 10,
+    "qwen3-vl-235b-a22b-instruct": 4,
+    "qwen3-vl-235b-a22b-thinking": 10,
+
     "qwen2.5-vl-7b-instruct": 4,
     "qwen2.5-vl-32b-instruct": 4,
     "qwen2.5-vl-72b-instruct": 4,
@@ -1626,6 +1677,9 @@ COMPLETION_RATIO = {
     "deepseek-v3-1-250821": 3,
     "deepseek-v3-1-think": 3,
 
+    "deepseek-v3-1-terminus": 3,
+    "deepseek-v3.1-terminus": 3,
+
     'deepseek-r1': 4,
     "deepseek-r1-160k": 5,
 
